parametrize_from_file.Namespace
===============================

.. currentmodule:: parametrize_from_file

.. autoclass:: Namespace
   :members:
   :undoc-members:
   :special-members:
   :private-members:
   :inherited-members:
   :show-inheritance:

   .. autoclasstoc:: 